<?php

/*------------------------------------------*/
/* WPZOOM: Testimonials           			*/
/*------------------------------------------*/

class wpzoom_testimonial extends WP_Widget {

	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wpzoom-testimonial', 'description' => 'Displays latest testimonials in a slider' );

		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wpzoom-testimonial' );

		/* Create the widget. */
		parent::__construct( 'wpzoom-testimonial', 'WPZOOM: Testimonial Slider', $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {

		extract( $args );

		/* User-selected settings. */
		$title 	= apply_filters('widget_title', $instance['title'] );
		$show_photo = $instance['show_photo'];
		$show_author = $instance['show_author'];
		$show_author_position = $instance['show_author_position'];
		$show_author_company = $instance['show_author_company'];
		$show_author_company_link = $instance['show_author_company_link'];
		$random_post = $instance['random_post'];
        $show_count     = $instance['show_count'];

		/* Before widget (defined by themes). */
		echo $before_widget;


		/* Title of widget (before and after defined by themes). */

		if ( $title )
			echo $before_title . $title . $after_title;

        ?>

        <script type="text/javascript">
            jQuery(function($){
                $('#testimonial-slider-<?php echo $widget_id; ?>').flexslider({
                    selector: 'ul > li',
                    controlNav: false,
                    directionNav: true,
                    animationLoop: true,
                    animation: 'slide',
                    slideshow: true,
                    useCSS: true,
                    smoothHeight: false,
                    animationSpeed: 300,
                    minItems: 1,
                    maxItems: 1
                });
            });
            </script>

        <?php

		if ($random_post == 'on')
		{
			$orderby = 'rand';
		}
		else
		{
			$orderby = 'date';
		}

		$loop = new WP_Query( array( 'post_type' => 'testimonial', 'posts_per_page' => $show_count, 'orderby' => $orderby) );


        ?>

        <div id="testimonial-slider-<?php echo $widget_id; ?>" class="testomonial_wrapper">

            <ul class="slides">

                <?php


        		while ( $loop->have_posts() ) : $loop->the_post();

        		$customFields = get_post_custom();

        		if ($show_author == 'on') {
        			$testimonial_author = $customFields['wpzoom_testimonial_author'][0];
        		}
        		if ($show_author_position == 'on') {
        			$testimonial_position = $customFields['wpzoom_testimonial_author_position'][0];
        		}
        		if ($show_author_company == 'on') {
        			$testimonial_company = $customFields['wpzoom_testimonial_author_company'][0];
        		}
        		if ($show_author_company_link == 'on') {
        			$testimonial_company_url = $customFields['wpzoom_testimonial_author_company_url'][0];
        		}

        		?>


                <li>

    			    <blockquote><?php the_content(); ?></blockquote>

                    <div class="testimonial_footer">
                        <?php
                            if ($show_photo == 'on') {

                                if ( has_post_thumbnail() ) : ?>
                                    <div class="testimonial-thumb">
                                        <?php the_post_thumbnail('testimonial-widget-author-photo'); ?>
                                    </div>
                                <?php endif;

                            }

                        ?>

                        <div class="testimonial_details">

                            <?php

                            if ($testimonial_author) echo "<h4>$testimonial_author</h4>";


                            if ($testimonial_position) echo "<span class=\"position\">$testimonial_position</span>";

                            if ($testimonial_company & $testimonial_position) { echo ", "; }


                            if ($testimonial_company) {
                                echo '<span class="company">';
                                if ($testimonial_company_url) echo "<a href=\"$testimonial_company_url\">";
                                echo $testimonial_company;
                                if ($testimonial_company_url) echo '</a>';
                                echo '</span>';
                            }

                            ?>

                        </div>

                    </div>

                </li>

    			<?php
    			endwhile;

    			//Reset query_posts
    			wp_reset_query();

                ?>

            </ul><!-- /.slides -->

        </div><!-- /.testimonial -->

        <?php

		/* After widget (defined by themes). */
		echo $after_widget;
	}


	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['show_photo'] = $new_instance['show_photo'];
		$instance['show_author'] = $new_instance['show_author'];
		$instance['show_author_position'] = $new_instance['show_author_position'];
		$instance['show_author_company'] = $new_instance['show_author_company'];
		$instance['show_author_company_link'] = $new_instance['show_author_company_link'];
		$instance['random_post'] = $new_instance['random_post'];
        $instance['show_count'] = $new_instance['show_count'];
		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => '', 'show_title' => 'on', 'show_count' => 3, 'show_photo' => 'on', 'show_author' => 'on', 'show_author_position' => 'on', 'show_author_company' => 'on', 'show_author_company_link' => 'on', 'random_post' => 'on');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Widget Title:', 'wpzoom'); ?></label><br />
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" type="text" class="widefat" size="35" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('show_photo'); ?>" name="<?php echo $this->get_field_name('show_photo'); ?>" <?php if ($instance['show_photo'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('show_photo'); ?>"><?php _e('Display author photo', 'wpzoom'); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('show_author'); ?>" name="<?php echo $this->get_field_name('show_author'); ?>" <?php if ($instance['show_author'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('show_author'); ?>"><?php _e('Display author name', 'wpzoom'); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('show_author_position'); ?>" name="<?php echo $this->get_field_name('show_author_position'); ?>" <?php if ($instance['show_author_position'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('show_author_position'); ?>"><?php _e('Display author position', 'wpzoom'); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('show_author_company'); ?>" name="<?php echo $this->get_field_name('show_author_company'); ?>" <?php if ($instance['show_author_company'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('show_author_company'); ?>"><?php _e('Display author company', 'wpzoom'); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('show_author_company_link'); ?>" name="<?php echo $this->get_field_name('show_author_company_link'); ?>" <?php if ($instance['show_author_company_link'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('show_author_company_link'); ?>"><?php _e('Link author company', 'wpzoom'); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('random_post'); ?>" name="<?php echo $this->get_field_name('random_post'); ?>" <?php if ($instance['random_post'] == 'on') { echo ' checked="checked"';  } ?> />
			<label for="<?php echo $this->get_field_id('random_post'); ?>"><?php _e('Order Randomly', 'wpzoom'); ?></label>
		</p>

        <p>
            <label for="<?php echo $this->get_field_id( 'show_count' ); ?>"><?php _e('Show:', 'wpzoom'); ?></label>
            <input id="<?php echo $this->get_field_id( 'show_count' ); ?>" name="<?php echo $this->get_field_name( 'show_count' ); ?>" value="<?php echo $instance['show_count']; ?>" type="text" size="2" /> <?php _e('testimonials', 'wpzoom'); ?>
        </p>

		<?php
	}
}

function wpzoom_register_testimonials_widget() {
	register_widget('wpzoom_testimonial');
}
add_action('widgets_init', 'wpzoom_register_testimonials_widget');